@@ -399,7 +399,7 @@ void KEARasterBand::SetDescription(const char *pszDescription)
     try
     {
         this->m_pImageIO->setImageBandDescription(this->nBand, pszDescription);
-        GDALPamRasterBand::SetDescription(pszDescription);
+        GDALRasterBand::SetDescription(pszDescription);
     }
     catch (const kealib::KEAIOException &)
     {
@@ -721,9 +721,9 @@ CPLErr KEARasterBand::GetDefaultHistogram(double *pdfMin, double *pdfMax,
 {
     if (bForce)
     {
-        return GDALPamRasterBand::GetDefaultHistogram(pdfMin, pdfMax, pnBuckets,
-                                                      ppanHistogram, bForce, fn,
-                                                      pProgressData);
+        return GDALRasterBand::GetDefaultHistogram(pdfMin, pdfMax, pnBuckets,
+                                                   ppanHistogram, bForce, fn,
+                                                   pProgressData);
     }
     else
     {
@@ -1379,7 +1379,7 @@ GDALRasterBand *KEARasterBand::GetMaskBand()
             {
                 // use the base class implementation - GDAL will delete
                 // fprintf( stderr, "returning base GetMaskBand()\n" );
-                m_pMaskBand = GDALPamRasterBand::GetMaskBand();
+                m_pMaskBand = GDALRasterBand::GetMaskBand();
             }
         }
         catch (const kealib::KEAException &)
@@ -1399,7 +1399,7 @@ int KEARasterBand::GetMaskFlags()
             // need to return the base class one since we are using
             // the base class implementation of GetMaskBand()
             // fprintf( stderr, "returning base GetMaskFlags()\n" );
-            return GDALPamRasterBand::GetMaskFlags();
+            return GDALRasterBand::GetMaskFlags();
         }
     }
     catch (const kealib::KEAException &)
