@@ -128,7 +128,9 @@ CPLErr SRTMHGTRasterBand::IReadBlock(int /*nBlockXOff*/, int nBlockYOff,
     /*      Load the desired data into the working buffer.                  */
     /* -------------------------------------------------------------------- */
     const int nDTSize = GDALGetDataTypeSizeBytes(eDataType);
-    VSIFSeekL(poGDS->fpImage, nBlockYOff * nBlockXSize * nDTSize, SEEK_SET);
+    VSIFSeekL(poGDS->fpImage,
+              static_cast<size_t>(nBlockYOff) * nBlockXSize * nDTSize,
+              SEEK_SET);
     VSIFReadL((unsigned char *)pImage, nBlockXSize, nDTSize, poGDS->fpImage);
 #ifdef CPL_LSB
     GDALSwapWords(pImage, nDTSize, nBlockXSize, nDTSize);
@@ -150,12 +152,15 @@ CPLErr SRTMHGTRasterBand::IWriteBlock(int /*nBlockXOff*/, int nBlockYOff,
         return CE_Failure;
 
     const int nDTSize = GDALGetDataTypeSizeBytes(eDataType);
-    VSIFSeekL(poGDS->fpImage, nBlockYOff * nBlockXSize * nDTSize, SEEK_SET);
+    VSIFSeekL(poGDS->fpImage,
+              static_cast<size_t>(nBlockYOff) * nBlockXSize * nDTSize,
+              SEEK_SET);
 
 #ifdef CPL_LSB
     if (nDTSize > 1)
     {
-        memcpy(poGDS->pabyBuffer, pImage, nBlockXSize * nDTSize);
+        memcpy(poGDS->pabyBuffer, pImage,
+               static_cast<size_t>(nBlockXSize) * nDTSize);
         GDALSwapWords(poGDS->pabyBuffer, nDTSize, nBlockXSize, nDTSize);
         VSIFWriteL(reinterpret_cast<unsigned char *>(poGDS->pabyBuffer),
                    nBlockXSize, nDTSize, poGDS->fpImage);
@@ -339,11 +344,12 @@ int SRTMHGTDataset::Identify(GDALOpenInfo *poOpenInfo)
 
     if (VSIStatL(poOpenInfo->pszFilename, &fileStat) != 0)
         return FALSE;
-    if (fileStat.st_size != 3601 * 3601 &&
+    if (fileStat.st_size != 1201 * 1201 * 2 &&
+        fileStat.st_size != 1801 * 3601 * 2 &&
+        fileStat.st_size != 3601 * 3601 &&
         fileStat.st_size != 3601 * 3601 * 2 &&
         fileStat.st_size != 3601 * 3601 * 4 &&  // .hgts
-        fileStat.st_size != 1801 * 3601 * 2 &&
-        fileStat.st_size != 1201 * 1201 * 2)
+        fileStat.st_size != 7201 * 7201 * 2)
         return FALSE;
 
     return TRUE;
@@ -438,6 +444,13 @@ GDALDataset *SRTMHGTDataset::Open(GDALOpenInfo *poOpenInfo)
     GDALDataType eDT = GDT_Int16;
     switch (fileStat.st_size)
     {
+        case 1201 * 1201 * 2:
+            numPixels_x = numPixels_y = 1201;
+            break;
+        case 1801 * 3601 * 2:
+            numPixels_x = 1801;
+            numPixels_y = 3601;
+            break;
         case 3601 * 3601:
             numPixels_x = numPixels_y = 3601;
             eDT = GDT_Byte;
@@ -449,12 +462,8 @@ GDALDataset *SRTMHGTDataset::Open(GDALOpenInfo *poOpenInfo)
             numPixels_x = numPixels_y = 3601;
             eDT = GDT_Float32;
             break;
-        case 1801 * 3601 * 2:
-            numPixels_x = 1801;
-            numPixels_y = 3601;
-            break;
-        case 1201 * 1201 * 2:
-            numPixels_x = numPixels_y = 1201;
+        case 7201 * 7201 * 2:
+            numPixels_x = numPixels_y = 7201;
             break;
         default:
             numPixels_x = numPixels_y = 0;
