@@ -49,6 +49,7 @@ class OGRGTFSDataset final : public GDALDataset
     {
         return static_cast<int>(m_apoLayers.size());
     }
+
     OGRLayer *GetLayer(int nIdx) override;
 
     static int Identify(GDALOpenInfo *poOpenInfo);
@@ -95,7 +96,7 @@ class OGRGTFSLayer final : public OGRLayer
     OGRFeature *GetNextFeature() override;
     int TestCapability(const char *) override;
     GIntBig GetFeatureCount(int bForce) override;
-    OGRErr SetAttributeFilter(const char *) override;
+
     OGRFeatureDefn *GetLayerDefn() override
     {
         return m_poFeatureDefn;
@@ -282,7 +283,7 @@ OGRFeature *OGRGTFSLayer::GetNextFeature()
         if (poSrcFeature == nullptr)
             return nullptr;
 
-        auto poFeature = cpl::make_unique<OGRFeature>(m_poFeatureDefn);
+        auto poFeature = std::make_unique<OGRFeature>(m_poFeatureDefn);
         const int nFieldCount = poSrcFeature->GetFieldCount();
         poFeature->SetFID(poSrcFeature->GetFID());
         auto poSrcLayerDefn = m_poUnderlyingLayer->GetLayerDefn();
@@ -347,30 +348,21 @@ OGRFeature *OGRGTFSLayer::GetNextFeature()
                 }
             }
         }
-        if (m_poFilterGeom == nullptr ||
-            FilterGeometry(poFeature->GetGeometryRef()))
+        if ((!m_poFilterGeom || FilterGeometry(poFeature->GetGeometryRef())) &&
+            (!m_poAttrQuery || m_poAttrQuery->Evaluate(poFeature.get())))
         {
             return poFeature.release();
         }
     }
 }
 
-/***********************************************************************/
-/*                       SetAttributeFilter()                          */
-/***********************************************************************/
-
-OGRErr OGRGTFSLayer::SetAttributeFilter(const char *pszFilter)
-{
-    return m_poUnderlyingLayer->SetAttributeFilter(pszFilter);
-}
-
 /***********************************************************************/
 /*                          GetFeatureCount()                          */
 /***********************************************************************/
 
 GIntBig OGRGTFSLayer::GetFeatureCount(int bForce)
 {
-    if (m_poFilterGeom != nullptr)
+    if (m_poFilterGeom || m_poAttrQuery)
         return OGRLayer::GetFeatureCount(bForce);
     return m_poUnderlyingLayer->GetFeatureCount(bForce);
 }
@@ -407,10 +399,12 @@ class OGRGTFSShapesGeomLayer final : public OGRLayer
     void ResetReading() override;
     OGRFeature *GetNextFeature() override;
     int TestCapability(const char *) override;
+
     OGRFeatureDefn *GetLayerDefn() override
     {
         return m_poFeatureDefn;
     }
+
     GIntBig GetFeatureCount(int bForce) override;
 };
 
@@ -482,7 +476,7 @@ void OGRGTFSShapesGeomLayer::Prepare()
         {
             const auto &osShapeId = kv.first;
             const auto &oMapPoints = kv.second;
-            auto poFeature = cpl::make_unique<OGRFeature>(m_poFeatureDefn);
+            auto poFeature = std::make_unique<OGRFeature>(m_poFeatureDefn);
             poFeature->SetField(0, osShapeId.c_str());
             OGRLineString *poLS = new OGRLineString();
             for (const auto &kv2 : oMapPoints)
@@ -629,7 +623,7 @@ GDALDataset *OGRGTFSDataset::Open(GDALOpenInfo *poOpenInfo)
 
     const std::string osCSVBaseDirPrefix(std::string("CSV:") + osBaseDir);
 
-    auto poDS = cpl::make_unique<OGRGTFSDataset>();
+    auto poDS = std::make_unique<OGRGTFSDataset>();
 
     char **papszFilenames = VSIReadDir(osBaseDir.c_str());
     size_t nCountFound = 0;
@@ -662,7 +656,7 @@ GDALDataset *OGRGTFSDataset::Open(GDALOpenInfo *poOpenInfo)
                 if (poSrcLayerDefn->GetFieldIndex("field_1") < 0)
                 {
                     poDS->m_apoLayers.emplace_back(
-                        cpl::make_unique<OGRGTFSLayer>(
+                        std::make_unique<OGRGTFSLayer>(
                             osCSVBaseDirPrefix, CPLGetBasename(*papszIter),
                             std::move(poCSVDataset)));
                 }
@@ -689,7 +683,7 @@ GDALDataset *OGRGTFSDataset::Open(GDALOpenInfo *poOpenInfo)
             if (poUnderlyingLayer)
             {
                 poDS->m_apoLayers.emplace_back(
-                    cpl::make_unique<OGRGTFSShapesGeomLayer>(
+                    std::make_unique<OGRGTFSShapesGeomLayer>(
                         std::move(poCSVDataset)));
             }
         }
