@@ -28,6 +28,7 @@
 
 #include "ogr_pgdump.h"
 #include "cpl_conv.h"
+#include "cpl_md5.h"
 #include "cpl_string.h"
 #include "ogr_p.h"
 
@@ -1554,6 +1555,77 @@ CPLString OGRPGCommonLayerGetPGDefault(OGRFieldDefn *poFieldDefn)
     return osRet;
 }
 
+/************************************************************************/
+/*                OGRPGCommonGenerateShortEnoughIdentifier()            */
+/************************************************************************/
+
+std::string OGRPGCommonGenerateShortEnoughIdentifier(const char *pszIdentifier)
+{
+    if (strlen(pszIdentifier) <= static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
+        return pszIdentifier;
+
+    constexpr int FIRST_8_CHARS_OF_MD5 = 8;
+    std::string osRet(pszIdentifier,
+                      OGR_PG_NAMEDATALEN - 1 - 1 - FIRST_8_CHARS_OF_MD5);
+    osRet += '_';
+    osRet += std::string(CPLMD5String(pszIdentifier), FIRST_8_CHARS_OF_MD5);
+    return osRet;
+}
+
+/************************************************************************/
+/*                 OGRPGCommonGenerateSpatialIndexName()                 */
+/************************************************************************/
+
+/** Generates the name of the spatial index on table pszTableName
+ * using pszGeomFieldName, such that it fits in OGR_PG_NAMEDATALEN - 1 bytes.
+ * The index of the geometry field may be used if the geometry field name
+ * is too long.
+ */
+std::string OGRPGCommonGenerateSpatialIndexName(const char *pszTableName,
+                                                const char *pszGeomFieldName,
+                                                int nGeomFieldIdx)
+{
+    // Nominal case: use full table and geometry field name
+    for (const char *pszSuffix : {"_geom_idx", "_idx"})
+    {
+        if (strlen(pszTableName) + 1 + strlen(pszGeomFieldName) +
+                strlen(pszSuffix) <=
+            static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
+        {
+            std::string osRet(pszTableName);
+            osRet += '_';
+            osRet += pszGeomFieldName;
+            osRet += pszSuffix;
+            return osRet;
+        }
+    }
+
+    // Slightly degraded case: use table name and geometry field index
+    const std::string osGeomFieldIdx(CPLSPrintf("%d", nGeomFieldIdx));
+    if (strlen(pszTableName) + 1 + osGeomFieldIdx.size() +
+            strlen("_geom_idx") <=
+        static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
+    {
+        std::string osRet(pszTableName);
+        osRet += '_';
+        osRet += osGeomFieldIdx;
+        osRet += "_geom_idx";
+        return osRet;
+    }
+
+    // Fallback case: use first characters of table name,
+    // first 8 chars of its MD5 and then the geometry field index.
+    constexpr int FIRST_8_CHARS_OF_MD5 = 8;
+    std::string osSuffix("_");
+    osSuffix += std::string(CPLMD5String(pszTableName), FIRST_8_CHARS_OF_MD5);
+    osSuffix += '_';
+    osSuffix += osGeomFieldIdx;
+    osSuffix += "_geom_idx";
+    std::string osRet(pszTableName, OGR_PG_NAMEDATALEN - 1 - osSuffix.size());
+    osRet += osSuffix;
+    return osRet;
+}
+
 /************************************************************************/
 /*                           GetNextFeature()                           */
 /************************************************************************/
@@ -1812,26 +1884,9 @@ OGRErr OGRPGDumpLayer::CreateGeomField(const OGRGeomFieldDefn *poGeomFieldIn,
 
         if (m_bCreateSpatialIndexFlag)
         {
-            std::string osIndexName(GetName());
-            std::string osSuffix("_");
-            osSuffix += poGeomField->GetNameRef();
-            osSuffix += "_geom_idx";
-            if (m_bLaunderColumnNames)
-            {
-                if (osSuffix.size() >=
-                    static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
-                {
-                    osSuffix = "_";
-                    osSuffix +=
-                        CPLSPrintf("%d", m_poFeatureDefn->GetGeomFieldCount());
-                    osSuffix += "_geom_idx";
-                }
-                if (osIndexName.size() + osSuffix.size() >
-                    static_cast<size_t>(OGR_PG_NAMEDATALEN - 1))
-                    osIndexName.resize(OGR_PG_NAMEDATALEN - 1 -
-                                       osSuffix.size());
-            }
-            osIndexName += osSuffix;
+            const std::string osIndexName(OGRPGCommonGenerateSpatialIndexName(
+                GetName(), poGeomField->GetNameRef(),
+                m_poFeatureDefn->GetGeomFieldCount()));
 
             osCommand.Printf(
                 "CREATE INDEX %s ON %s USING %s (%s)",
